@@ -36,6 +36,11 @@ from telegram_payment_bot.translation_loader import TranslationLoader
 
 # Message dispatcher class
 class MessageDispatcher:
+
+    config: Config
+    logger: Logger
+    translator: TranslationLoader
+
     # Constructor
     def __init__(self,
                  config: Config,
